@@ -1,5 +1,7 @@
 """Trivial version test."""
 
+from __future__ import annotations
+
 import json
 import tempfile
 import unittest
@@ -8,6 +10,7 @@ from tempfile import TemporaryDirectory
 
 import pandas as pd
 import rdflib
+from pydantic import ValidationError
 
 import curies
 from curies.api import (
@@ -19,7 +22,6 @@ from curies.api import (
     ExpansionError,
     NamableReference,
     NamedReference,
-    NoCURIEDelimiterError,
     PrefixStandardizationError,
     Record,
     Records,
@@ -36,6 +38,7 @@ from curies.sources import (
     get_monarch_converter,
     get_obo_converter,
 )
+from curies.utils import NoCURIEDelimiterError
 from curies.version import get_version
 from tests.constants import SLOW
 
@@ -72,7 +75,7 @@ class TestStruct(unittest.TestCase):
 
     def test_records(self) -> None:
         """Test a list of records."""
-        records = Records.parse_obj([{"prefix": "chebi", "uri_prefix": CHEBI_URI_PREFIX}])
+        records = Records.model_validate([{"prefix": "chebi", "uri_prefix": CHEBI_URI_PREFIX}])
         converter = Converter(records=records)
         self.assertEqual({"chebi"}, converter.get_prefixes())
 
@@ -123,6 +126,53 @@ class TestStruct(unittest.TestCase):
         self.assertIn(NamableReference.from_curie("a:1", "name1"), references_2)
         self.assertIn(NamedReference.from_curie("a:1", "name1"), references_2)
 
+    def test_tuple(self) -> None:
+        """Test reference tuples."""
+        t = ReferenceTuple.from_curie("a:1")
+        self.assertEqual(Reference(prefix="a", identifier="1"), t.to_pydantic())
+
+    def test_reference_constructor(self) -> None:
+        """Test constructing a reference."""
+        r1 = Reference(prefix="a", identifier="1")
+        r2 = NamableReference(prefix="a", identifier="2")
+        r3 = NamableReference(prefix="a", identifier="3", name="item 3")
+        r4 = NamedReference(prefix="a", identifier="4", name="item 4")
+
+        self.assertEqual(Reference(prefix="a", identifier="1"), Reference.from_reference(r1))
+        self.assertEqual(Reference(prefix="a", identifier="2"), Reference.from_reference(r2))
+        self.assertEqual(Reference(prefix="a", identifier="3"), Reference.from_reference(r3))
+        self.assertEqual(Reference(prefix="a", identifier="4"), Reference.from_reference(r4))
+
+        self.assertEqual(
+            NamableReference(prefix="a", identifier="1", name=None),
+            NamableReference.from_reference(r1),
+        )
+        self.assertEqual(
+            NamableReference(prefix="a", identifier="2", name=None),
+            NamableReference.from_reference(r2),
+        )
+        self.assertEqual(
+            NamableReference(prefix="a", identifier="3", name="item 3"),
+            NamableReference.from_reference(r3),
+        )
+        self.assertEqual(
+            NamableReference(prefix="a", identifier="4", name="item 4"),
+            NamableReference.from_reference(r4),
+        )
+
+        with self.assertRaises(TypeError):
+            NamedReference.from_reference(r1)
+        with self.assertRaises(ValidationError):
+            NamedReference.from_reference(r2)
+        self.assertEqual(
+            NamedReference(prefix="a", identifier="3", name="item 3"),
+            NamedReference.from_reference(r3),
+        )
+        self.assertEqual(
+            NamedReference(prefix="a", identifier="4", name="item 4"),
+            NamedReference.from_reference(r4),
+        )
+
 
 class TestAddRecord(unittest.TestCase):
     """Test adding records."""
@@ -863,6 +913,230 @@ class TestConverter(unittest.TestCase):
         converter_2 = Converter.from_rdflib(graph.namespace_manager)
         self._assert_convert(converter_2)
 
+    def test_parse_curie(self) -> None:
+        """Tests for parse CURIE."""
+        converter = Converter(
+            records=[
+                Record(
+                    prefix="GO",
+                    uri_prefix="http://purl.obolibrary.org/obo/GO_",
+                    prefix_synonyms=["go"],
+                )
+            ]
+        )
+        self.assertEqual(
+            ReferenceTuple("GO", "1234567"), converter.parse_curie("GO:1234567", strict=True)
+        )
+        self.assertEqual(
+            ReferenceTuple("GO", "1234567"), converter.parse_curie("GO:1234567", strict=False)
+        )
+        self.assertEqual(
+            ReferenceTuple("GO", "1234567"), converter.parse_curie("go:1234567", strict=True)
+        )
+        self.assertEqual(
+            ReferenceTuple("GO", "1234567"), converter.parse_curie("go:1234567", strict=False)
+        )
+
+        self.assertIsNone(converter.parse_curie("NOPE:NOPE", strict=False))
+        with self.assertRaises(PrefixStandardizationError):
+            converter.parse_curie("NOPE:NOPE", strict=True)
+
+    def test_parse(self) -> None:
+        """Test parsing URI or CURIE."""
+        converter = Converter(
+            records=[
+                Record(
+                    prefix="GO",
+                    uri_prefix="http://purl.obolibrary.org/obo/GO_",
+                    prefix_synonyms=["go"],
+                    uri_prefix_synonyms=["https://identifiers.org/GO:"],
+                )
+            ]
+        )
+        curie = "GO:1234567"
+        curie2 = "go:1234567"
+        uri = "http://purl.obolibrary.org/obo/GO_1234567"
+        uri2 = "https://identifiers.org/GO:1234567"
+
+        for s in [curie, curie2, uri, uri2]:
+            self.assertEqual(ReferenceTuple("GO", "1234567"), converter.parse(s, strict=True))
+            self.assertEqual(ReferenceTuple("GO", "1234567"), converter.parse(s, strict=False))
+
+        # test invalid CURIE parsing
+        self.assertIsNone(converter.parse("NOPE:NOPE", strict=False))
+        with self.assertRaises(ValueError):
+            converter.parse_uri("NOPE:NOPE", strict=True)
+
+        # test invalid URI parsing
+        self.assertIsNone(converter.parse("https://example.org/nope", strict=False))
+        with self.assertRaises(ValueError):
+            converter.parse_uri("https://example.org/nope", strict=True)
+
+        # test whatever's left
+        self.assertIsNone(converter.parse("1234567", strict=False))
+        with self.assertRaises(ValueError):
+            converter.parse_uri("1234567", strict=True)
+
+    def test_compress_or_standardize(self) -> None:
+        """Test standardizing URI or CURIE."""
+        converter = Converter(
+            records=[
+                Record(
+                    prefix="GO",
+                    uri_prefix="http://purl.obolibrary.org/obo/GO_",
+                    prefix_synonyms=["go"],
+                    uri_prefix_synonyms=["https://identifiers.org/GO:"],
+                )
+            ]
+        )
+        curie = "GO:1234567"
+        curie2 = "go:1234567"
+        uri = "http://purl.obolibrary.org/obo/GO_1234567"
+        uri2 = "https://identifiers.org/GO:1234567"
+
+        for s in [curie, curie2, uri, uri2]:
+            self.assertEqual(
+                "GO:1234567", converter.compress_or_standardize(s, strict=True, passthrough=True)
+            )
+            self.assertEqual(
+                "GO:1234567", converter.compress_or_standardize(s, strict=False, passthrough=True)
+            )
+            self.assertEqual(
+                "GO:1234567", converter.compress_or_standardize(s, strict=True, passthrough=False)
+            )
+            self.assertEqual(
+                "GO:1234567", converter.compress_or_standardize(s, strict=False, passthrough=False)
+            )
+
+        self.assertIsNone(
+            converter.compress_or_standardize("NOPE:NOPE", strict=False, passthrough=False)
+        )
+        self.assertEqual(
+            "NOPE:NOPE",
+            converter.compress_or_standardize("NOPE:NOPE", strict=False, passthrough=True),
+        )
+        with self.assertRaises(ValueError):
+            converter.compress_or_standardize("NOPE:NOPE", strict=True, passthrough=True)
+        with self.assertRaises(ValueError):
+            converter.compress_or_standardize("NOPE:NOPE", strict=True, passthrough=False)
+
+    def test_parse_uri(self) -> None:
+        """Tests for parsing URIs."""
+        converter = Converter(
+            records=[
+                Record(
+                    prefix="GO",
+                    uri_prefix="http://purl.obolibrary.org/obo/GO_",
+                    prefix_synonyms=["go"],
+                    uri_prefix_synonyms=["https://identifiers.org/GO:"],
+                )
+            ]
+        )
+        uri = "http://purl.obolibrary.org/obo/GO_1234567"
+        uri2 = "https://identifiers.org/GO:1234567"
+
+        self.assertEqual(ReferenceTuple("GO", "1234567"), converter.parse_uri(uri, strict=True))
+        self.assertEqual(ReferenceTuple("GO", "1234567"), converter.parse_uri(uri, strict=False))
+
+        self.assertEqual(ReferenceTuple("GO", "1234567"), converter.parse_uri(uri2, strict=True))
+        self.assertEqual(ReferenceTuple("GO", "1234567"), converter.parse_uri(uri2, strict=False))
+
+        self.assertEqual(
+            (None, None), converter.parse_uri("123345", strict=False, return_none=False)
+        )
+        self.assertIsNone(converter.parse_uri("123345", strict=False, return_none=True))
+        with self.assertRaises(ValueError):
+            converter.parse_uri("123345", strict=True)
+
+    def test_expand(self) -> None:
+        """Tests for expand."""
+        converter = Converter(
+            records=[
+                Record(
+                    prefix="GO",
+                    uri_prefix="http://purl.obolibrary.org/obo/GO_",
+                    prefix_synonyms=["go"],
+                )
+            ]
+        )
+        uri = "http://purl.obolibrary.org/obo/GO_1234567"
+        self.assertEqual(uri, converter.expand("GO:1234567", strict=True, passthrough=True))
+        self.assertEqual(uri, converter.expand("GO:1234567", strict=False, passthrough=True))
+        self.assertEqual(uri, converter.expand("GO:1234567", strict=True, passthrough=False))
+        self.assertEqual(uri, converter.expand("GO:1234567", strict=False, passthrough=False))
+
+        self.assertEqual(uri, converter.expand("go:1234567", strict=True, passthrough=True))
+        self.assertEqual(uri, converter.expand("go:1234567", strict=False, passthrough=True))
+        self.assertEqual(uri, converter.expand("go:1234567", strict=True, passthrough=False))
+        self.assertEqual(uri, converter.expand("go:1234567", strict=False, passthrough=False))
+
+        self.assertEqual("NOPE:NOPE", converter.expand("NOPE:NOPE", strict=False, passthrough=True))
+        self.assertIsNone(converter.expand("NOPE:NOPE", strict=False, passthrough=False))
+
+        with self.assertRaises(ExpansionError):
+            converter.expand("NOPE:NOPE", strict=True, passthrough=True)
+        with self.assertRaises(ExpansionError):
+            converter.expand("NOPE:NOPE", strict=True, passthrough=False)
+
+    def test_expand_pair_all(self) -> None:
+        """Tests for expand."""
+        converter = Converter(
+            records=[
+                Record(
+                    prefix="GO",
+                    uri_prefix="http://purl.obolibrary.org/obo/GO_",
+                    prefix_synonyms=["go"],
+                    uri_prefix_synonyms=["https://identifiers.org/GO:"],
+                )
+            ]
+        )
+        uris = ["http://purl.obolibrary.org/obo/GO_1234567", "https://identifiers.org/GO:1234567"]
+        self.assertEqual(uris, converter.expand_pair_all("GO", "1234567", strict=True))
+        self.assertEqual(uris, converter.expand_pair_all("GO", "1234567", strict=False))
+
+        # with synonym as input
+        self.assertEqual(uris, converter.expand_pair_all("go", "1234567", strict=True))
+        self.assertEqual(uris, converter.expand_pair_all("go", "1234567", strict=False))
+
+        self.assertIsNone(converter.expand_pair_all("NOPE", "NOPE", strict=False))
+        with self.assertRaises(ExpansionError):
+            converter.expand_pair_all("NOPE", "NOPE", strict=True)
+
+    def test_expand_reference(self) -> None:
+        """Tests for expand."""
+        converter = Converter(
+            records=[
+                Record(
+                    prefix="GO",
+                    uri_prefix="http://purl.obolibrary.org/obo/GO_",
+                    prefix_synonyms=["go"],
+                )
+            ]
+        )
+        uri = "http://purl.obolibrary.org/obo/GO_1234567"
+        ref = ReferenceTuple("GO", "1234567")
+        ref2 = ReferenceTuple("go", "1234567")
+        nope = ReferenceTuple("NOPE", "NOPE")
+        self.assertEqual(uri, converter.expand_reference(ref, strict=True, passthrough=True))
+        self.assertEqual(uri, converter.expand_reference(ref, strict=False, passthrough=True))
+        self.assertEqual(uri, converter.expand_reference(ref, strict=True, passthrough=False))
+        self.assertEqual(uri, converter.expand_reference(ref, strict=False, passthrough=False))
+
+        self.assertEqual(uri, converter.expand_reference(ref2, strict=True, passthrough=True))
+        self.assertEqual(uri, converter.expand_reference(ref2, strict=False, passthrough=True))
+        self.assertEqual(uri, converter.expand_reference(ref2, strict=True, passthrough=False))
+        self.assertEqual(uri, converter.expand_reference(ref2, strict=False, passthrough=False))
+
+        self.assertEqual(
+            "NOPE:NOPE", converter.expand_reference(nope, strict=False, passthrough=True)
+        )
+        self.assertIsNone(converter.expand_reference(nope, strict=False, passthrough=False))
+
+        with self.assertRaises(ExpansionError):
+            converter.expand_reference(nope, strict=True, passthrough=True)
+        with self.assertRaises(ExpansionError):
+            converter.expand_reference(nope, strict=True, passthrough=False)
+
     def test_expand_all(self) -> None:
         """Test expand all."""
         priority_prefix_map = {
@@ -880,6 +1154,8 @@ class TestConverter(unittest.TestCase):
             converter.expand_all("CHEBI:138488"),
         )
         self.assertIsNone(converter.expand_all("NOPE:NOPE"))
+        with self.assertRaises(PrefixStandardizationError):
+            converter.expand_all("NOPE:NOPE", strict=True)
 
     def test_expand_ambiguous(self) -> None:
         """Test expansion of URI or CURIEs."""
@@ -967,6 +1243,45 @@ class TestConverter(unittest.TestCase):
             ),
         )
 
+    def test_standardize_identifier(self) -> None:
+        """Test standardizing identifiers."""
+
+        class BananaStripperConverter(Converter):
+            """A converter that removes bananas from LUIDs."""
+
+            def standardize_identifier(self, prefix: str, identifier: str) -> str | None:
+                """Standardize the identifier by removing a banana and checking it is numeric."""
+                norm_identifier = identifier.removeprefix(f"{prefix}:")
+
+                # now, do some validation
+                if not norm_identifier.isnumeric():
+                    return None
+
+                return norm_identifier
+
+        converter = BananaStripperConverter(
+            records=[
+                Record(
+                    prefix="CHEBI",
+                    prefix_synonyms=["chebi"],
+                    uri_prefix="http://purl.obolibrary.org/obo/CHEBI_",
+                    uri_prefix_synonyms=["https://identifiers.org/chebi:"],
+                ),
+            ]
+        )
+        self.assertEqual(ReferenceTuple("CHEBI", "1234"), converter.parse_curie("CHEBI:1234"))
+        self.assertEqual(ReferenceTuple("CHEBI", "1234"), converter.parse_curie("chebi:1234"))
+        self.assertEqual(ReferenceTuple("CHEBI", "1234"), converter.parse_curie("CHEBI:CHEBI:1234"))
+        self.assertEqual(ReferenceTuple("CHEBI", "1234"), converter.parse_curie("chebi:CHEBI:1234"))
+        self.assertIsNone(converter.parse_curie("NOPE:NOPE:1234", strict=False))
+
+        self.assertIsNone(converter.parse_curie("CHEBI:nope", strict=False))
+        # does not solve the problem of synonyms in the banana, this is specific
+        # to the current implementation in this test
+        self.assertIsNone(converter.parse_curie("chebi:chebi:1234", strict=False))
+        with self.assertRaises(ValueError):
+            converter.parse_curie("CHEBI:nope", strict=True)
+
 
 class TestVersion(unittest.TestCase):
     """Trivially test a version."""
